@@ -31,20 +31,22 @@ DEFAULT_N_PRIOR_EXCLUDED = 1
 GITHUB_PAGE = "https://github.com/asreview/asreview"
 EMAIL_ADDRESS = "asreview@uu.nl"
 
-STATE_EXTENSIONS = ['.h5', '.hdf5', '.he5', '.json']
+STATE_EXTENSIONS = [".h5", ".hdf5", ".he5", ".json"]
 LOGGER_EXTENSIONS = STATE_EXTENSIONS
 
-COLUMN_DEFINITIONS = [
-    [
+COLUMN_DEFINITIONS = {
+    # included
+    "included": [
         "final_included", "label", "label_included", "included_label",
         "included_final", "included", "included_flag", "include"
     ],
-    [
+    # abstract included (pending deprecation)
+    "abstract_included": [
         "abstract_included", "included_abstract", "included_after_abstract",
         "label_abstract_screening"
     ],
-    ['title', 'primary_title'],
-    ['authors', 'author names', 'first_authors'],
-    ['abstract', 'abstract note'],
-    ['keywords'],
-]
+    "title": ["title", "primary_title"],
+    "authors": ["authors", "author names", "first_authors"],
+    "abstract": ["abstract", "abstract note", "notes_abstract"],
+    "keywords": ["keywords"],
+}
