@@ -88,7 +88,7 @@ def get_fuzzy_scores(keywords, match_strings):
 
     Returns
     -------
-    np.ndarray:
+    numpy.ndarray
         Array of scores ordered in the same way as the str_list input.
     """
     return token_set_ratio(keywords, match_strings)
@@ -99,7 +99,7 @@ class ASReviewData():
 
     Arguments
     ---------
-    df: pd.DataFrame
+    df: pandas.DataFrame
         Dataframe containing the data for the ASReview data object.
     data_name: str
         Give a name to the data object.
@@ -135,8 +135,8 @@ class ASReviewData():
         else:
             self.column_spec = column_spec
 
-        if "final_included" not in self.column_spec:
-            self.column_spec["final_included"] = "final_included"
+        if "included" not in self.column_spec:
+            self.column_spec["included"] = "included"
 
         if data_type == "included":
             self.labels = np.ones(len(self), dtype=int)
@@ -161,25 +161,27 @@ class ASReviewData():
         return hashlib.sha1(" ".join(texts).encode(
             encoding='UTF-8', errors='ignore')).hexdigest()
 
-    def slice(self, idx):
+    def slice(self, idx, by_index=True):
         """Create a slice from itself.
 
         Useful if some parts should be kept/thrown away.
 
         Arguments
         ---------
-        idx: list, np.ndarray
+        idx: list, numpy.ndarray
             Record ids that should be kept.
 
         Returns
         -------
-        ASReviewData:
+        ASReviewData
             Slice of itself.
         """
         if self.df is None:
             raise ValueError("Cannot slice empty ASReviewData object.")
 
-        return ASReviewData(self.df[idx], data_name="sliced")
+        if by_index:
+            return ASReviewData(self.df.iloc[idx], data_name="sliced")
+        return ASReviewData(self.df.loc[idx, :], data_name="sliced")
 
     def append(self, as_data):
         """Append another ASReviewData object.
@@ -240,9 +242,9 @@ class ASReviewData():
 
         Arguments
         ---------
-        fp: str, Path
+        fp: str, pathlib.Path
             Read the data from this file.
-        read_fn: function
+        read_fn: callable
             Function to read the file. It should return a standardized
             dataframe.
         data_name: str
@@ -298,7 +300,7 @@ class ASReviewData():
 
         Returns
         -------
-        PaperRecord:
+        PaperRecord
             The corresponding record if i was an integer, or a list of records
             if i was an iterable.
         """
@@ -374,15 +376,16 @@ class ASReviewData():
             Don't return records below this threshold.
         max_return: int
             Maximum number of records to return.
-        exclude: list, np.ndarray
+        exclude: list, numpy.ndarray
             List of indices that should be excluded in the search. You would
             put papers that were already labeled here for example.
         by_index: bool
             If True, use internal indexing.
             If False, use record ids for indexing.
+
         Returns
         -------
-        list:
+        list
             Sorted list of indexes that match best the keywords.
         """
         new_ranking = get_fuzzy_scores(keywords, self.match_string)
@@ -472,17 +475,25 @@ class ASReviewData():
         return convert_array[self.prior_idx]
 
     @property
+    def included(self):
+        return self.labels
+
+    @included.setter
+    def included(self, labels):
+        self.labels = labels
+
+    @property  # pending deprecation
     def final_included(self):
         return self.labels
 
-    @final_included.setter
+    @final_included.setter  # pending deprecation
     def final_included(self, labels):
         self.labels = labels
 
     @property
     def labels(self):
         try:
-            column = self.column_spec["final_included"]
+            column = self.column_spec["included"]
             return self.df[column].values
         except KeyError:
             return None
@@ -490,10 +501,10 @@ class ASReviewData():
     @labels.setter
     def labels(self, labels):
         try:
-            column = self.column_spec["final_included"]
+            column = self.column_spec["included"]
             self.df[column] = labels
         except KeyError:
-            self.df["final_included"] = labels
+            self.df["included"] = labels
 
     @property
     def abstract_included(self):
@@ -518,7 +529,7 @@ class ASReviewData():
 
         Returns
         -------
-        np.array:
+        numpy.ndarray
             Array of indices that have the 'initial' property.
         """
         query_src = state.startup_vals()["query_src"]
@@ -542,9 +553,9 @@ class ASReviewData():
         ---------
         fp: str
             Filepath to export to.
-        labels: list, np.array
+        labels: list, numpy.ndarray
             Labels to be inserted into the dataframe before export.
-        ranking: list, np.array
+        ranking: list, numpy.ndarray
             Optionally, dataframe rows can be reordered.
         """
         if Path(fp).suffix in [".csv", ".CSV"]:
@@ -563,7 +574,7 @@ class ASReviewData():
 
         Arguments
         ---------
-        labels: list, np.ndarray
+        labels: list, numpy.ndarray
             Current labels will be overwritten by these labels
             (including unlabelled). No effect if labels is None.
         ranking: list
@@ -572,11 +583,11 @@ class ASReviewData():
 
         Returns
         -------
-        pd.DataFrame:
+        pandas.DataFrame
             Dataframe of all available record data.
         """
         new_df = pd.DataFrame.copy(self.df)
-        col = self.column_spec["final_included"]
+        col = self.column_spec["included"]
         if labels is not None:
             new_df[col] = labels
         if ranking is not None:
@@ -597,7 +608,7 @@ class ASReviewData():
         ---------
         fp: str, NoneType
             Filepath or None for buffer.
-        labels: list, np.ndarray
+        labels: list, numpy.ndarray
             Current labels will be overwritten by these labels
             (including unlabelled). No effect if labels is None.
         ranking: list
@@ -606,7 +617,7 @@ class ASReviewData():
 
         Returns
         -------
-        pd.DataFrame:
+        pandas.DataFrame
             Dataframe of all available record data.
         """
         df = self.to_dataframe(labels=labels, ranking=ranking)
@@ -619,7 +630,7 @@ class ASReviewData():
         ---------
         fp: str, NoneType
             Filepath or None for buffer.
-        labels: list, np.ndarray
+        labels: list, numpy.ndarray
             Current labels will be overwritten by these labels
             (including unlabelled). No effect if labels is None.
         ranking: list
@@ -628,7 +639,7 @@ class ASReviewData():
 
         Returns
         -------
-        pd.DataFrame:
+        pandas.DataFrame
             Dataframe of all available record data.
         """
         df = self.to_dataframe(labels=labels, ranking=ranking)
