@@ -1,6 +1,6 @@
 import logging
 
-from asreview.ascii import welcome_message
+from asreview.batch import batch_simulate
 from asreview.config import DEFAULT_BALANCE_STRATEGY
 from asreview.config import DEFAULT_FEATURE_EXTRACTION
 from asreview.config import DEFAULT_MODEL
@@ -30,7 +30,6 @@ class SimulateEntryPoint(BaseEntryPoint):
         elif verbose >= 2:
             logging.getLogger().setLevel(logging.DEBUG)
 
-        print(welcome_message())
         review_simulate(path, **args_dict)
 
 
@@ -59,7 +58,7 @@ def _simulate_parser(prog="simulate", description=DESCRIPTION_SIMULATE):
         default=DEFAULT_N_PRIOR_INCLUDED,
         type=int,
         help="Sample n prior included papers. "
-             "Only used when --prior_included is not given. "
+             "Only used when --prior_idx is not given. "
              f"Default {DEFAULT_N_PRIOR_INCLUDED}")
 
     parser.add_argument(
@@ -67,7 +66,7 @@ def _simulate_parser(prog="simulate", description=DESCRIPTION_SIMULATE):
         default=DEFAULT_N_PRIOR_EXCLUDED,
         type=int,
         help="Sample n prior excluded papers. "
-             "Only used when --prior_excluded is not given. "
+             "Only used when --prior_idx is not given. "
              f"Default {DEFAULT_N_PRIOR_EXCLUDED}")
 
     parser.add_argument(
@@ -165,15 +164,6 @@ def _simulate_parser(prog="simulate", description=DESCRIPTION_SIMULATE):
              "the program stops after all documents are reviewed or is "
              "interrupted by the user."
     )
-    parser.add_argument(
-        "--abstract_only",
-        default=False,
-        action='store_true',
-        help="Simulate using the labels of abstract screening. "
-             "This is option is useful if there is both a column for "
-             "abstract and final screening available in the dataset. "
-             "Default False."
-    )
     parser.add_argument(
         "--verbose", "-v",
         default=0,
@@ -182,3 +172,34 @@ def _simulate_parser(prog="simulate", description=DESCRIPTION_SIMULATE):
     )
 
     return parser
+
+
+class BatchEntryPoint(BaseEntryPoint):
+    description = "Parallel simulation for ASReview."
+
+    def execute(self, argv):
+        parser = _batch_parser()
+        kwargs = vars(parser.parse_args(argv))
+        batch_simulate(**kwargs)
+
+
+DESCRIPTION_BATCH = """
+Automated Systematic Review (ASReview) batch system for simulation runs.
+
+It has the same interface as the simulation modus, but adds an extra option
+(--n_runs) to run a batch of simulation runs with the same configuration.
+"""
+
+
+def _batch_parser():
+    parser = _simulate_parser(
+        prog="simulate-batch",
+        description=DESCRIPTION_BATCH
+    )
+    parser.add_argument(
+        "-r", "--n_run",
+        default=10,
+        type=int,
+        help="Number of runs to perform."
+    )
+    return parser
