@@ -18,12 +18,12 @@ import warnings
 
 import numpy as np
 
-from asreview.balance_strategies.simple import SimpleBalance
+from asreview.models.balance.simple import SimpleBalance
 from asreview.config import DEFAULT_N_INSTANCES, LABEL_NA
-from asreview.feature_extraction.tfidf import Tfidf
-from asreview.models.nb import NBModel
-from asreview.query_strategies.max import MaxQuery
-from asreview.query_strategies.random import RandomQuery
+from asreview.models.feature_extraction.tfidf import Tfidf
+from asreview.models.classifiers import NaiveBayesClassifier
+from asreview.models.query.max import MaxQuery
+from asreview.models.query.random import RandomQuery
 from asreview.settings import ASReviewSettings
 from asreview.state.utils import open_state
 
@@ -38,9 +38,9 @@ def _merge_prior_knowledge(included, excluded, return_labels=True):
 
     Parameters
     ----------
-    included: numpy.array
+    included: numpy.ndarray
         Array of indices which should be included.
-    excluded: numpy.array
+    excluded: numpy.ndarray
         Array of indices which should be excluded.
     return_labels: bool
         Return the labels of the merged priors.
@@ -99,7 +99,7 @@ class BaseReview(ABC):
         process.
     n_queries: int
         Number of steps/queries to perform. Set to None for no limit.
-    start_idx: numpy.array
+    start_idx: numpy.ndarray
         Start the simulation/review with these indices. They are assumed to
         be already labeled. Failing to do so might result bad behaviour.
     state_file: str
@@ -127,7 +127,7 @@ class BaseReview(ABC):
 
         # Default to Naive Bayes model
         if model is None:
-            model = NBModel()
+            model = NaiveBayesClassifier()
         if query_model is None:
             query_model = MaxQuery()
         if balance_model is None:
@@ -374,7 +374,7 @@ class BaseReview(ABC):
 
         Returns
         -------
-        np.array:
+        numpy.ndarray:
             Indices of records queried.
         """
 
@@ -409,9 +409,9 @@ class BaseReview(ABC):
 
         Arguments
         ---------
-        query_idx: list, np.array
+        query_idx: list, numpy.ndarray
             Indices to classify.
-        inclusions: list, np.array
+        inclusions: list, numpy.ndarray
             Labels of the query_idx.
         state: BaseLogger
             Logger to store the classification in.
