@@ -19,9 +19,10 @@ from flask import current_app as app
 from flask import request
 from flask import Response
 from flask import send_file
-from flask.json import jsonify
+from flask import jsonify
 from flask_cors import CORS
 from werkzeug.utils import secure_filename
+from werkzeug.exceptions import InternalServerError
 
 from asreview import __version__ as asreview_version
 from asreview.datasets import DatasetManager
@@ -64,6 +65,38 @@ bp = Blueprint('api', __name__, url_prefix='/api')
 CORS(bp, resources={r"*": {"origins": "*"}})
 
 
+# custom errors
+
+class ProjectNotFoundError(Exception):
+    status_code = 400
+
+
+# error handlers
+
+@bp.errorhandler(ProjectNotFoundError)
+def project_not_found(e):
+
+    message = str(e) if str(e) else "Project not found."
+    logging.error(message)
+    return jsonify(message=message), e.status_code
+
+
+@bp.errorhandler(InternalServerError)
+def error_500(e):
+    original = getattr(e, "original_exception", None)
+
+    if original is None:
+        # direct 500 error, such as abort(500)
+        logging.error(e)
+        return jsonify(message="Whoops, something went wrong."), 500
+
+    # wrapped unhandled error
+    logging.error(e.original_exception)
+    return jsonify(message=str(e.original_exception)), 500
+
+
+# routes
+
 @bp.route('/projects', methods=["GET"])
 def api_get_projects():  # noqa: F401
     """Get info on the article"""
@@ -81,12 +114,23 @@ def api_get_projects():  # noqa: F401
             if "projectInitReady" not in res:
                 res["projectInitReady"] = True
 
+            # if time is not available (<0.14)
+            if "created_at_unix" not in res:
+                res["created_at_unix"] = None
+
             logging.info("Project found: {}".format(res["id"]))
             project_info.append(res)
 
         except Exception as err:
             logging.error(err)
 
+    # sort the projects based on created_at_unix
+    project_info = sorted(
+        project_info,
+        key=lambda y: (y["created_at_unix"] is not None, y["created_at_unix"]),
+        reverse=True
+    )
+
     response = jsonify({"result": project_info})
     response.headers.add('Access-Control-Allow-Origin', '*')
 
@@ -103,22 +147,15 @@ def api_init_project():  # noqa: F401
 
     project_id = re.sub('[^A-Za-z0-9]+', '-', project_name).lower()
 
-    try:
-        project_config = init_project(
-            project_id,
-            project_name=project_name,
-            project_description=project_description,
-            project_authors=project_authors)
+    project_config = init_project(
+        project_id,
+        project_name=project_name,
+        project_description=project_description,
+        project_authors=project_authors)
 
-        response = jsonify(project_config)
+    response = jsonify(project_config)
 
-    except Exception as err:
-        logging.error(err)
-        response = jsonify(message="project-init-failure")
-
-        return response, 500
-
-    return response
+    return response, 201
 
 
 @bp.route('/project/<project_id>/info', methods=["GET"])
@@ -156,21 +193,10 @@ def api_get_project_info(project_id):  # noqa: F401
             else:
                 project_info["projectInitReady"] = False
 
-        response = jsonify(project_info)
+    except FileNotFoundError:
+        raise ProjectNotFoundError()
 
-    except FileNotFoundError as err:
-        logging.error(err)
-        response = jsonify(message="Project not found.")
-
-        return response, 400
-
-    except Exception as err:
-        logging.error(err)
-        response = jsonify(message="Internal Server Error.")
-
-        return response, 500
-
-    return response
+    return jsonify(project_info)
 
 
 @bp.route('/project/<project_id>/info', methods=["PUT"])
@@ -379,7 +405,7 @@ def api_search_data(project_id):  # noqa: F401
                 "abstract": paper.abstract,
                 "authors": paper.authors,
                 "keywords": paper.keywords,
-                "included": int(paper.final_included)
+                "included": int(paper.included)
             })
 
     response = jsonify(payload)
@@ -635,65 +661,77 @@ def api_init_model_ready(project_id):  # noqa: F401
 def api_import_project():
     """Import uploaded project"""
 
-    import_project_id = None
-
-    if 'file' in request.files:
-
-        project_file = request.files['file']
-        filename = secure_filename(project_file.filename)
-
-        try:
-
-            with zipfile.ZipFile(project_file, "r") as zipObj:
-                FileNames = zipObj.namelist()
-
-                # check if the zip file contains a ASReview project
-                if sum([fn.endswith("project.json") for fn in FileNames]) == 1:
-
-                    # extract all files to a temporary folder
-                    tmpdir = tempfile.TemporaryDirectory()
-                    zipObj.extractall(path=tmpdir.name)
-
-                    for fn in FileNames:
-                        if fn.endswith("project.json"):
-                            fp = Path(tmpdir.name, fn)
-                            with open(fp, "r+") as f:
-                                project = json.load(f)
-
-                                # if the uploaded project already exists,
-                                # then make a copy
-                                if is_project(project["id"]):
-                                    project["id"] += " copy"
-                                    project["name"] += " copy"
-                                    f.seek(0)
-                                    json.dump(project, f)
-                                    f.truncate()
-                else:
-                    response = jsonify(
-                        message="No project found within the chosen file.")
-                    return response, 404
-            try:
-                # check if a copy of a project already exists
-                os.rename(tmpdir.name, asreview_path() / f"{project['id']}")
-
-                import_project_id = project['id']
-
-            except Exception as err:
-                logging.error(err)
-                response = jsonify(
-                    message=f"A copy of {project['id'][:-5]} already exists.")
-                return response, 400
-
-        except Exception as err:
-            logging.error(err)
-            response = jsonify(message=f"Failed to upload file '{filename}'.")
-            return response, 400
-    else:
+    # raise error if file not given
+    if 'file' not in request.files:
         response = jsonify(message="No file found to upload.")
         return response, 400
 
+    # import project id
+    import_project = None
+
+    # set the project file
+    project_file = request.files['file']
+
+    try:
+
+        with zipfile.ZipFile(project_file, "r") as zip_obj:
+            zip_filenames = zip_obj.namelist()
+
+            # raise error if no ASReview project file
+            if "project.json" not in zip_filenames:
+                response = jsonify(
+                    message="File doesn't contain valid project format.")
+                return response, 404
+
+            # extract all files to a temporary folder
+            tmpdir = tempfile.TemporaryDirectory()
+            zip_obj.extractall(path=tmpdir.name)
+
+            # Open the project file and check the id. The id needs to be
+            # unique, otherwise it is exended with -copy.
+            fp = Path(tmpdir.name, "project.json")
+            with open(fp, "r+") as f:
+
+                # load the project info in scope of function
+                import_project = json.load(f)
+
+                # If the uploaded project already exists,
+                # then overwrite project.json with a copy suffix.
+                while is_project(import_project["id"]):
+
+                    # project update
+                    import_project["id"] = f"{import_project['id']}-copy"
+                    import_project["name"] = f"{import_project['name']} copy"
+
+                else:
+                    # write to file
+                    f.seek(0)
+                    json.dump(import_project, f)
+                    f.truncate()
+
+    except Exception as err:
+        # Unknown error.
+        logging.error(err)
+        response = jsonify(
+            message="Unknown error when uploading project "
+            f"'{project_file.filename}'."
+        )
+        return response, 400
+
+    # location to copy file to
+    fp_copy = get_project_path(import_project["id"])
+
+    try:
+        # Move the project from the temp folder to the projects folder.
+        os.rename(tmpdir.name, fp_copy)
+
+    except Exception as err:
+        logging.error(err)
+        response = jsonify(message=f"Failed to copy project to {fp_copy}.")
+        return response, 400
+
     # return the project info in the same format as project_info
-    return api_get_project_info(import_project_id)
+    return api_get_project_info(import_project["id"])
 
 
 @bp.route('/project/<project_id>/export', methods=["GET"])
@@ -740,7 +778,7 @@ def export_project(project_id):
 
     # copy the source tree, but ignore pickle files
     shutil.copytree(
-        f"/Users/jonathan/.asreview/{project_id}",
+        get_project_path(project_id),
         Path(tmpdir.name, project_id),
         ignore=shutil.ignore_patterns('*.pickle')
     )
@@ -749,8 +787,7 @@ def export_project(project_id):
     shutil.make_archive(
         Path(tmpdir.name, project_id),
         "zip",
-        root_dir=Path(tmpdir.name),
-        base_dir=project_id
+        root_dir=Path(tmpdir.name, project_id)
     )
 
     # return the project file to the user
