@@ -3,6 +3,7 @@ import os
 import shutil
 import subprocess
 import sys
+import time
 from pathlib import Path
 
 import numpy as np
@@ -18,13 +19,16 @@ from asreview.webapp.utils.io import read_pool
 from asreview.webapp.utils.io import read_proba
 from asreview.webapp.utils.io import write_label_history
 from asreview.webapp.utils.io import write_pool
-from asreview.webapp.utils.paths import asreview_path
+from asreview.webapp.utils.paths import get_data_path
 from asreview.webapp.utils.paths import get_data_file_path
 from asreview.webapp.utils.paths import get_labeled_path
 from asreview.webapp.utils.paths import get_lock_path
 from asreview.webapp.utils.paths import get_pool_path
 from asreview.webapp.utils.paths import get_project_file_path
+from asreview.webapp.utils.paths import get_project_path
 from asreview.webapp.utils.paths import get_tmp_path
+from asreview.webapp.utils.paths import list_asreview_project_paths
+from asreview.webapp.utils.validation import is_project
 
 
 def _get_executable():
@@ -47,19 +51,14 @@ def init_project(project_id,
 
     if not project_id and not isinstance(project_id, str) \
             and len(project_id) >= 3:
-        raise ValueError("Project name can't be None or empty string")
+        raise ValueError("Project name should be at least 3 characters.")
 
-    # get the directory with the projects
-    project_dir = asreview_path() / project_id
-
-    if project_dir.exists():
-        raise ValueError("Project already exists")
+    if is_project(project_id):
+        raise ValueError("Project already exists.")
 
     try:
-        project_dir.mkdir()
-
-        fp_data = project_dir / "data"
-        fp_data.mkdir()
+        get_project_path(project_id).mkdir()
+        get_data_path(project_id).mkdir()
 
         project_config = {
             'version': asreview_version,  # todo: Fail without git?
@@ -67,6 +66,7 @@ def init_project(project_id,
             'name': project_name,
             'description': project_description,
             'authors': project_authors,
+            'created_at_unix': int(time.time()),
 
             # project related variables
             'projectInitReady': False,
@@ -81,7 +81,7 @@ def init_project(project_id,
 
     except Exception as err:
         # remove all generated folders and raise error
-        shutil.rmtree(project_dir)
+        shutil.rmtree(get_project_path())
         raise err
 
 
@@ -161,6 +161,34 @@ def remove_dataset_to_project(project_id, file_name):
         os.remove(str(labeled_path))
 
 
+def clean_project_tmp_files(project_id):
+    """Clean temporary files in a project.
+
+    Arguments
+    ---------
+    project_id: str
+        The id of the current project.
+    """
+    project_path = get_project_path(project_id)
+
+    # clean pickle files
+    for f_pickle in project_path.rglob("*.pickle"):
+        try:
+            os.remove(f_pickle)
+        except OSError as e:
+            print(f"Error: {f_pickle} : {e.strerror}")
+
+    # clean tmp export files
+    # TODO
+
+
+def clean_all_project_tmp_files():
+    """Clean temporary files in all projects.
+    """
+    for project_path in list_asreview_project_paths():
+        clean_project_tmp_files(project_path)
+
+
 def get_paper_data(project_id,
                    paper_id,
                    return_title=True,
